<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

do_action( 'woocommerce_before_checkout_form', $checkout );

// If checkout registration is disabled and not logged in, the user cannot checkout
if ( ! $checkout->enable_signup && ! $checkout->enable_guest_checkout && ! is_user_logged_in() ) {
	echo apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'hypermarket' ) );
	return;
}

?>

<form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">

	<?php if ( sizeof( $checkout->checkout_fields ) > 0 ) : ?>

		<?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>
		
		<!-- Checkout Form -->
		<div id="customer_details" class="<?php echo apply_filters('hypermarket_cart_checkout_order_details_offset', false) ? 'col-md-8' : 'col-lg-8'; ?>">
			<div class="row col-1">
				<?php do_action( 'woocommerce_checkout_billing' ); ?>
			</div><!-- .col-1 -->
			<div class="row col-2">
				<?php do_action( 'woocommerce_checkout_shipping' ); ?>
			</div><!-- .col-2 -->
		</div><!-- #customer_details -->

		<?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

	<?php endif; ?>
	
	<div class="<?php echo apply_filters('hypermarket_cart_checkout_order_details_offset', false) ? 'col-lg-3 col-lg-offset-1 col-md-4 col-md-offset-0' : 'col-lg-4'; ?> padding-top-half padding-bottom">
		<aside>
			<h3 id="order_review_heading" class="sr-only"><?php esc_html_e( 'Your order', 'hypermarket' ); ?></h3>
			<?php do_action( 'woocommerce_checkout_before_order_review' ); ?>
			<div id="order_review" class="woocommerce-checkout-review-order">
				<?php do_action( 'woocommerce_checkout_order_review' ); ?>
			</div><!-- #order_review -->
			<?php do_action( 'woocommerce_checkout_after_order_review' ); ?>
		</aside>
    </div><!-- .col-md-3 -->
</form><!-- .woocommerce-checkout -->

<?php do_action( 'woocommerce_after_checkout_form', $checkout ); ?>
